# citation-date

![Github CI](https://github.com/justmars/citation-date/actions/workflows/main.yml/badge.svg)

Regex date formula and decoder, eventually used by the dataset employed in [LawSQL](https://lawsql.com).

## Documentation

See [documentation](https://justmars.github.io/citation-date).

## Development

Checkout code, create a new virtual environment:

```sh
poetry add citation-date # python -m pip install citation-date
poetry update # install dependencies
poetry shell
```

Run tests:

```sh
pytest
```
